@@ -14,28 +14,30 @@ namespace stan {
       unvalued_argument()
         : _is_present(false) {}
 
-      void print(std::ostream* s, const int depth, const std::string prefix) {}
+      void print(interface_callbacks::writer::base_writer& w,
+                 const int depth,
+                 const std::string& prefix) {}
 
-      void print_help(std::ostream* s, const int depth,
+      void print_help(interface_callbacks::writer::base_writer& w,
+                      const int depth,
                       const bool recurse = false) {
-        if (!s)
-          return;
-
         std::string indent(indent_width * depth, ' ');
         std::string subindent(indent_width, ' ');
 
-        *s << indent << _name << std::endl;
-        *s << indent << subindent << _description << std::endl;
-        *s << std::endl;
+        w(indent + _name);
+        w(indent + subindent + _description);
+        w();
       }
 
-      bool parse_args(std::vector<std::string>& args, std::ostream* out,
-                      std::ostream* err, bool& help_flag) {
+      bool parse_args(std::vector<std::string>& args,
+                      interface_callbacks::writer::base_writer& info,
+                      interface_callbacks::writer::base_writer& err,
+                      bool& help_flag) {
         if (args.size() == 0)
           return true;
 
         if ((args.back() == "help") || (args.back() == "help-all")) {
-          print_help(out, 0);
+          print_help(info, 0);
           help_flag |= true;
           args.clear();
           return true;
