@@ -1,9 +1,9 @@
 #ifndef STAN_MATH_FWD_SCAL_FUN_ERF_HPP
 #define STAN_MATH_FWD_SCAL_FUN_ERF_HPP
 
-#include <math.h>
 #include <stan/math/fwd/core.hpp>
 #include <stan/math/prim/scal/fun/constants.hpp>
+#include <stan/math/prim/scal/fun/erf.hpp>
 #include <stan/math/prim/scal/fun/square.hpp>
 #include <cmath>
 
@@ -12,8 +12,6 @@ namespace stan {
 
     template <typename T>
     inline fvar<T> erf(const fvar<T>& x) {
-      using ::erf;
-      using std::sqrt;
       using std::exp;
       return fvar<T>(erf(x.val_),
                      x.d_ * exp(-square(x.val_)) * TWO_OVER_SQRT_PI);
