@@ -12,9 +12,8 @@ namespace stan {
     template <typename T>
     inline fvar<T>
     exp2(const fvar<T>& x) {
-      using stan::math::exp2;
       using std::log;
-      return fvar<T>(exp2(x.val_), x.d_ * exp2(x.val_) * stan::math::LOG_2);
+      return fvar<T>(exp2(x.val_), x.d_ * exp2(x.val_) * LOG_2);
     }
 
   }
