@@ -23,7 +23,7 @@ namespace stan {
     template <typename T>
     inline
     fvar<T>
-    lbeta(const double x1, const fvar<T>& x2) {
+    lbeta(double x1, const fvar<T>& x2) {
       using boost::math::digamma;
       return fvar<T>(lbeta(x1, x2.val_),
                      x2.d_ * digamma(x2.val_) - x2.d_ * digamma(x1 + x2.val_));
@@ -32,7 +32,7 @@ namespace stan {
     template <typename T>
     inline
     fvar<T>
-    lbeta(const fvar<T>& x1, const double x2) {
+    lbeta(const fvar<T>& x1, double x2) {
       using boost::math::digamma;
       return fvar<T>(lbeta(x1.val_, x2),
                      x1.d_ * digamma(x1.val_) - x1.d_ * digamma(x1.val_ + x2));
