@@ -7,7 +7,7 @@
 namespace stan {
   namespace math {
     /**
-     * Return <code>true</code> if the specified matrix is a valid
+     * Check if the specified matrix is a valid
      * covariance matrix.
      *
      * A valid covariance matrix is a square, symmetric matrix that is
@@ -19,7 +19,6 @@ namespace stan {
      * @param name Variable name (for error messages)
      * @param y Matrix to test
      *
-     * @return <code>true</code> if the matrix is a valid covariance matrix
      * @throw <code>std::invalid_argument</code> if the matrix is not square
      *   or if the matrix is 0x0
      * @throw <code>std::domain_error</code> if the matrix is not symmetric,
@@ -27,14 +26,11 @@ namespace stan {
      *   or if any element of the matrix is nan
      */
     template <typename T_y>
-    inline bool
-    check_cov_matrix(
-      const char* function,
-      const char* name,
-      const Eigen::Matrix<T_y, Eigen::Dynamic, Eigen::Dynamic>& y
-    ) {
+    inline void
+    check_cov_matrix(const char* function,
+                     const char* name,
+                  const Eigen::Matrix<T_y, Eigen::Dynamic, Eigen::Dynamic>& y) {
       check_pos_definite(function, name, y);
-      return true;
     }
 
   }
