@@ -20,7 +20,7 @@ namespace stan {
     inline
     typename boost::math::tools::promote_args<T>::type
     sd(const std::vector<T>& v) {
-      stan::math::check_nonzero_size("sd", "v", v);
+      check_nonzero_size("sd", "v", v);
       if (v.size() == 1) return 0.0;
       return sqrt(variance(v));
     }
@@ -35,8 +35,7 @@ namespace stan {
     inline
     typename boost::math::tools::promote_args<T>::type
     sd(const Eigen::Matrix<T, R, C>& m) {
-      // FIXME: redundant with test in variance; second line saves sqrt
-      stan::math::check_nonzero_size("sd", "m", m);
+      check_nonzero_size("sd", "m", m);
       if (m.size() == 1) return 0.0;
       return sqrt(variance(m));
     }
