@@ -17,18 +17,17 @@ namespace stan {
     trace_gen_quad_form(const Eigen::Matrix<double, RD, CD> &D,
                         const Eigen::Matrix<double, RA, CA> &A,
                         const Eigen::Matrix<double, RB, CB> &B) {
-      stan::math::check_square("trace_gen_quad_form", "A", A);
-      stan::math::check_square("trace_gen_quad_form", "D", D);
-      stan::math::check_multiplicable("trace_gen_quad_form",
-                                      "A", A,
-                                      "B", B);
-      stan::math::check_multiplicable("trace_gen_quad_form",
-                                      "B", B,
-                                      "D", D);
+      check_square("trace_gen_quad_form", "A", A);
+      check_square("trace_gen_quad_form", "D", D);
+      check_multiplicable("trace_gen_quad_form",
+                          "A", A,
+                          "B", B);
+      check_multiplicable("trace_gen_quad_form",
+                          "B", B,
+                          "D", D);
       return (D*B.transpose()*A*B).trace();
     }
+
   }
 }
-
 #endif
-
