@@ -39,7 +39,6 @@
 #include <stan/math/prim/scal/err/check_bounded.hpp>
 #include <stan/math/prim/scal/err/check_consistent_size.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
-#include <stan/math/prim/scal/err/check_equal.hpp>
 #include <stan/math/prim/scal/err/check_finite.hpp>
 #include <stan/math/prim/scal/err/check_greater.hpp>
 #include <stan/math/prim/scal/err/check_greater_or_equal.hpp>
@@ -171,155 +170,246 @@
 #include <stan/math/prim/scal/prob/bernoulli_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/bernoulli_cdf.hpp>
 #include <stan/math/prim/scal/prob/bernoulli_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/bernoulli_lccdf.hpp>
+#include <stan/math/prim/scal/prob/bernoulli_lcdf.hpp>
 #include <stan/math/prim/scal/prob/bernoulli_log.hpp>
 #include <stan/math/prim/scal/prob/bernoulli_logit_log.hpp>
-#include <stan/math/prim/scal/prob/bernoulli_rng.hpp>
+#include <stan/math/prim/scal/prob/bernoulli_logit_lpmf.hpp>
 #include <stan/math/prim/scal/prob/bernoulli_logit_rng.hpp>
+#include <stan/math/prim/scal/prob/bernoulli_lpmf.hpp>
+#include <stan/math/prim/scal/prob/bernoulli_rng.hpp>
 #include <stan/math/prim/scal/prob/beta_binomial_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/beta_binomial_cdf.hpp>
 #include <stan/math/prim/scal/prob/beta_binomial_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/beta_binomial_lccdf.hpp>
+#include <stan/math/prim/scal/prob/beta_binomial_lcdf.hpp>
 #include <stan/math/prim/scal/prob/beta_binomial_log.hpp>
+#include <stan/math/prim/scal/prob/beta_binomial_lpmf.hpp>
 #include <stan/math/prim/scal/prob/beta_binomial_rng.hpp>
 #include <stan/math/prim/scal/prob/beta_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/beta_cdf.hpp>
 #include <stan/math/prim/scal/prob/beta_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/beta_lccdf.hpp>
+#include <stan/math/prim/scal/prob/beta_lcdf.hpp>
 #include <stan/math/prim/scal/prob/beta_log.hpp>
+#include <stan/math/prim/scal/prob/beta_lpdf.hpp>
 #include <stan/math/prim/scal/prob/beta_rng.hpp>
 #include <stan/math/prim/scal/prob/binomial_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/binomial_cdf.hpp>
 #include <stan/math/prim/scal/prob/binomial_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/binomial_lccdf.hpp>
+#include <stan/math/prim/scal/prob/binomial_lcdf.hpp>
 #include <stan/math/prim/scal/prob/binomial_log.hpp>
-#include <stan/math/prim/scal/prob/binomial_logit_log.hpp>
+#include <stan/math/prim/scal/prob/binomial_lpmf.hpp>
 #include <stan/math/prim/scal/prob/binomial_rng.hpp>
+#include <stan/math/prim/scal/prob/binomial_logit_log.hpp>
+#include <stan/math/prim/scal/prob/binomial_logit_lpmf.hpp>
 #include <stan/math/prim/scal/prob/cauchy_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/cauchy_cdf.hpp>
 #include <stan/math/prim/scal/prob/cauchy_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/cauchy_lccdf.hpp>
+#include <stan/math/prim/scal/prob/cauchy_lcdf.hpp>
 #include <stan/math/prim/scal/prob/cauchy_log.hpp>
+#include <stan/math/prim/scal/prob/cauchy_lpdf.hpp>
 #include <stan/math/prim/scal/prob/cauchy_rng.hpp>
 #include <stan/math/prim/scal/prob/chi_square_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/chi_square_cdf.hpp>
 #include <stan/math/prim/scal/prob/chi_square_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/chi_square_lccdf.hpp>
+#include <stan/math/prim/scal/prob/chi_square_lcdf.hpp>
 #include <stan/math/prim/scal/prob/chi_square_log.hpp>
+#include <stan/math/prim/scal/prob/chi_square_lpdf.hpp>
 #include <stan/math/prim/scal/prob/chi_square_rng.hpp>
 #include <stan/math/prim/scal/prob/double_exponential_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/double_exponential_cdf.hpp>
 #include <stan/math/prim/scal/prob/double_exponential_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/double_exponential_lccdf.hpp>
+#include <stan/math/prim/scal/prob/double_exponential_lcdf.hpp>
 #include <stan/math/prim/scal/prob/double_exponential_log.hpp>
+#include <stan/math/prim/scal/prob/double_exponential_lpdf.hpp>
 #include <stan/math/prim/scal/prob/double_exponential_rng.hpp>
 #include <stan/math/prim/scal/prob/exp_mod_normal_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/exp_mod_normal_cdf.hpp>
 #include <stan/math/prim/scal/prob/exp_mod_normal_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/exp_mod_normal_lccdf.hpp>
+#include <stan/math/prim/scal/prob/exp_mod_normal_lcdf.hpp>
 #include <stan/math/prim/scal/prob/exp_mod_normal_log.hpp>
+#include <stan/math/prim/scal/prob/exp_mod_normal_lpdf.hpp>
 #include <stan/math/prim/scal/prob/exp_mod_normal_rng.hpp>
 #include <stan/math/prim/scal/prob/exponential_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/exponential_cdf.hpp>
 #include <stan/math/prim/scal/prob/exponential_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/exponential_lccdf.hpp>
+#include <stan/math/prim/scal/prob/exponential_lcdf.hpp>
 #include <stan/math/prim/scal/prob/exponential_log.hpp>
+#include <stan/math/prim/scal/prob/exponential_lpdf.hpp>
 #include <stan/math/prim/scal/prob/exponential_rng.hpp>
 #include <stan/math/prim/scal/prob/frechet_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/frechet_cdf.hpp>
 #include <stan/math/prim/scal/prob/frechet_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/frechet_lccdf.hpp>
+#include <stan/math/prim/scal/prob/frechet_lcdf.hpp>
 #include <stan/math/prim/scal/prob/frechet_log.hpp>
+#include <stan/math/prim/scal/prob/frechet_lpdf.hpp>
 #include <stan/math/prim/scal/prob/frechet_rng.hpp>
 #include <stan/math/prim/scal/prob/gamma_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/gamma_cdf.hpp>
 #include <stan/math/prim/scal/prob/gamma_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/gamma_lccdf.hpp>
+#include <stan/math/prim/scal/prob/gamma_lcdf.hpp>
 #include <stan/math/prim/scal/prob/gamma_log.hpp>
+#include <stan/math/prim/scal/prob/gamma_lpdf.hpp>
 #include <stan/math/prim/scal/prob/gamma_rng.hpp>
 #include <stan/math/prim/scal/prob/gumbel_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/gumbel_cdf.hpp>
 #include <stan/math/prim/scal/prob/gumbel_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/gumbel_lccdf.hpp>
+#include <stan/math/prim/scal/prob/gumbel_lcdf.hpp>
 #include <stan/math/prim/scal/prob/gumbel_log.hpp>
+#include <stan/math/prim/scal/prob/gumbel_lpdf.hpp>
 #include <stan/math/prim/scal/prob/gumbel_rng.hpp>
 #include <stan/math/prim/scal/prob/hypergeometric_log.hpp>
+#include <stan/math/prim/scal/prob/hypergeometric_lpmf.hpp>
 #include <stan/math/prim/scal/prob/hypergeometric_rng.hpp>
 #include <stan/math/prim/scal/prob/inv_chi_square_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/inv_chi_square_cdf.hpp>
 #include <stan/math/prim/scal/prob/inv_chi_square_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/inv_chi_square_lccdf.hpp>
+#include <stan/math/prim/scal/prob/inv_chi_square_lcdf.hpp>
 #include <stan/math/prim/scal/prob/inv_chi_square_log.hpp>
+#include <stan/math/prim/scal/prob/inv_chi_square_lpdf.hpp>
 #include <stan/math/prim/scal/prob/inv_chi_square_rng.hpp>
 #include <stan/math/prim/scal/prob/inv_gamma_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/inv_gamma_cdf.hpp>
 #include <stan/math/prim/scal/prob/inv_gamma_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/inv_gamma_lccdf.hpp>
+#include <stan/math/prim/scal/prob/inv_gamma_lcdf.hpp>
 #include <stan/math/prim/scal/prob/inv_gamma_log.hpp>
+#include <stan/math/prim/scal/prob/inv_gamma_lpdf.hpp>
 #include <stan/math/prim/scal/prob/inv_gamma_rng.hpp>
 #include <stan/math/prim/scal/prob/logistic_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/logistic_cdf.hpp>
 #include <stan/math/prim/scal/prob/logistic_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/logistic_lccdf.hpp>
+#include <stan/math/prim/scal/prob/logistic_lcdf.hpp>
 #include <stan/math/prim/scal/prob/logistic_log.hpp>
+#include <stan/math/prim/scal/prob/logistic_lpdf.hpp>
 #include <stan/math/prim/scal/prob/logistic_rng.hpp>
 #include <stan/math/prim/scal/prob/lognormal_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/lognormal_cdf.hpp>
 #include <stan/math/prim/scal/prob/lognormal_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/lognormal_lccdf.hpp>
+#include <stan/math/prim/scal/prob/lognormal_lcdf.hpp>
 #include <stan/math/prim/scal/prob/lognormal_log.hpp>
+#include <stan/math/prim/scal/prob/lognormal_lpdf.hpp>
 #include <stan/math/prim/scal/prob/lognormal_rng.hpp>
 #include <stan/math/prim/scal/prob/neg_binomial_2_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/neg_binomial_2_cdf.hpp>
 #include <stan/math/prim/scal/prob/neg_binomial_2_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/neg_binomial_2_lccdf.hpp>
+#include <stan/math/prim/scal/prob/neg_binomial_2_lcdf.hpp>
 #include <stan/math/prim/scal/prob/neg_binomial_2_log.hpp>
-#include <stan/math/prim/scal/prob/neg_binomial_2_log_log.hpp>
-#include <stan/math/prim/scal/prob/neg_binomial_2_log_rng.hpp>
+#include <stan/math/prim/scal/prob/neg_binomial_2_lpmf.hpp>
 #include <stan/math/prim/scal/prob/neg_binomial_2_rng.hpp>
+#include <stan/math/prim/scal/prob/neg_binomial_2_log_log.hpp>
+#include <stan/math/prim/scal/prob/neg_binomial_2_log_lpmf.hpp>
+#include <stan/math/prim/scal/prob/neg_binomial_2_log_rng.hpp>
 #include <stan/math/prim/scal/prob/neg_binomial_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/neg_binomial_cdf.hpp>
 #include <stan/math/prim/scal/prob/neg_binomial_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/neg_binomial_lccdf.hpp>
+#include <stan/math/prim/scal/prob/neg_binomial_lcdf.hpp>
 #include <stan/math/prim/scal/prob/neg_binomial_log.hpp>
+#include <stan/math/prim/scal/prob/neg_binomial_lpmf.hpp>
 #include <stan/math/prim/scal/prob/neg_binomial_rng.hpp>
 #include <stan/math/prim/scal/prob/normal_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/normal_cdf.hpp>
 #include <stan/math/prim/scal/prob/normal_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/normal_lccdf.hpp>
+#include <stan/math/prim/scal/prob/normal_lcdf.hpp>
 #include <stan/math/prim/scal/prob/normal_log.hpp>
+#include <stan/math/prim/scal/prob/normal_lpdf.hpp>
 #include <stan/math/prim/scal/prob/normal_rng.hpp>
 #include <stan/math/prim/scal/prob/pareto_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/pareto_cdf.hpp>
 #include <stan/math/prim/scal/prob/pareto_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/pareto_lccdf.hpp>
+#include <stan/math/prim/scal/prob/pareto_lcdf.hpp>
 #include <stan/math/prim/scal/prob/pareto_log.hpp>
+#include <stan/math/prim/scal/prob/pareto_lpdf.hpp>
 #include <stan/math/prim/scal/prob/pareto_rng.hpp>
 #include <stan/math/prim/scal/prob/pareto_type_2_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/pareto_type_2_cdf.hpp>
 #include <stan/math/prim/scal/prob/pareto_type_2_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/pareto_type_2_lccdf.hpp>
+#include <stan/math/prim/scal/prob/pareto_type_2_lcdf.hpp>
 #include <stan/math/prim/scal/prob/pareto_type_2_log.hpp>
+#include <stan/math/prim/scal/prob/pareto_type_2_lpdf.hpp>
 #include <stan/math/prim/scal/prob/pareto_type_2_rng.hpp>
 #include <stan/math/prim/scal/prob/poisson_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/poisson_cdf.hpp>
 #include <stan/math/prim/scal/prob/poisson_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/poisson_lccdf.hpp>
+#include <stan/math/prim/scal/prob/poisson_lcdf.hpp>
 #include <stan/math/prim/scal/prob/poisson_log.hpp>
-#include <stan/math/prim/scal/prob/poisson_log_log.hpp>
-#include <stan/math/prim/scal/prob/poisson_log_rng.hpp>
+#include <stan/math/prim/scal/prob/poisson_lpmf.hpp>
 #include <stan/math/prim/scal/prob/poisson_rng.hpp>
+#include <stan/math/prim/scal/prob/poisson_log_log.hpp>
+#include <stan/math/prim/scal/prob/poisson_log_lpmf.hpp>
+#include <stan/math/prim/scal/prob/poisson_log_rng.hpp>
 #include <stan/math/prim/scal/prob/rayleigh_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/rayleigh_cdf.hpp>
 #include <stan/math/prim/scal/prob/rayleigh_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/rayleigh_lccdf.hpp>
+#include <stan/math/prim/scal/prob/rayleigh_lcdf.hpp>
 #include <stan/math/prim/scal/prob/rayleigh_log.hpp>
+#include <stan/math/prim/scal/prob/rayleigh_lpdf.hpp>
 #include <stan/math/prim/scal/prob/rayleigh_rng.hpp>
 #include <stan/math/prim/scal/prob/scaled_inv_chi_square_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/scaled_inv_chi_square_cdf.hpp>
 #include <stan/math/prim/scal/prob/scaled_inv_chi_square_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/scaled_inv_chi_square_lccdf.hpp>
+#include <stan/math/prim/scal/prob/scaled_inv_chi_square_lcdf.hpp>
 #include <stan/math/prim/scal/prob/scaled_inv_chi_square_log.hpp>
+#include <stan/math/prim/scal/prob/scaled_inv_chi_square_lpdf.hpp>
 #include <stan/math/prim/scal/prob/scaled_inv_chi_square_rng.hpp>
 #include <stan/math/prim/scal/prob/skew_normal_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/skew_normal_cdf.hpp>
 #include <stan/math/prim/scal/prob/skew_normal_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/skew_normal_lccdf.hpp>
+#include <stan/math/prim/scal/prob/skew_normal_lcdf.hpp>
 #include <stan/math/prim/scal/prob/skew_normal_log.hpp>
+#include <stan/math/prim/scal/prob/skew_normal_lpdf.hpp>
 #include <stan/math/prim/scal/prob/skew_normal_rng.hpp>
 #include <stan/math/prim/scal/prob/student_t_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/student_t_cdf.hpp>
 #include <stan/math/prim/scal/prob/student_t_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/student_t_lccdf.hpp>
+#include <stan/math/prim/scal/prob/student_t_lcdf.hpp>
 #include <stan/math/prim/scal/prob/student_t_log.hpp>
+#include <stan/math/prim/scal/prob/student_t_lpdf.hpp>
 #include <stan/math/prim/scal/prob/student_t_rng.hpp>
 #include <stan/math/prim/scal/prob/uniform_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/uniform_cdf.hpp>
 #include <stan/math/prim/scal/prob/uniform_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/uniform_lccdf.hpp>
+#include <stan/math/prim/scal/prob/uniform_lcdf.hpp>
 #include <stan/math/prim/scal/prob/uniform_log.hpp>
+#include <stan/math/prim/scal/prob/uniform_lpdf.hpp>
 #include <stan/math/prim/scal/prob/uniform_rng.hpp>
 #include <stan/math/prim/scal/prob/von_mises_log.hpp>
+#include <stan/math/prim/scal/prob/von_mises_lpdf.hpp>
 #include <stan/math/prim/scal/prob/von_mises_rng.hpp>
 #include <stan/math/prim/scal/prob/weibull_ccdf_log.hpp>
 #include <stan/math/prim/scal/prob/weibull_cdf.hpp>
 #include <stan/math/prim/scal/prob/weibull_cdf_log.hpp>
+#include <stan/math/prim/scal/prob/weibull_lccdf.hpp>
+#include <stan/math/prim/scal/prob/weibull_lcdf.hpp>
 #include <stan/math/prim/scal/prob/weibull_log.hpp>
+#include <stan/math/prim/scal/prob/weibull_lpdf.hpp>
 #include <stan/math/prim/scal/prob/weibull_rng.hpp>
 #include <stan/math/prim/scal/prob/wiener_log.hpp>
+#include <stan/math/prim/scal/prob/wiener_lpdf.hpp>
 
 #include <cmath>
 
