@@ -16,7 +16,7 @@ namespace stan {
 
       template <typename T_y, bool is_vec>
       struct positive {
-        static bool check(const char* function,
+        static void check(const char* function,
                           const char* name,
                           const T_y& y) {
           // have to use not is_unsigned. is_signed will be false
@@ -24,13 +24,12 @@ namespace stan {
           if (!boost::is_unsigned<T_y>::value && !(y > 0))
             domain_error(function, name, y,
                          "is ", ", but must be > 0!");
-          return true;
         }
       };
 
       template <typename T_y>
       struct positive<T_y, true> {
-        static bool check(const char* function,
+        static void check(const char* function,
                           const char* name,
                           const T_y& y) {
           using stan::length;
@@ -40,14 +39,13 @@ namespace stan {
               domain_error_vec(function, name, y, n,
                                "is ", ", but must be > 0!");
           }
-          return true;
         }
       };
 
     }
 
     /**
-     * Return <code>true</code> if <code>y</code> is positive.
+     * Check if <code>y</code> is positive.
      *
      * This function is vectorized and will check each element of
      * <code>y</code>.
@@ -58,16 +56,14 @@ namespace stan {
      * @param name Variable name (for error messages)
      * @param y Variable to check
      *
-     * @return <code>true</code> if y is greater than 0.
      * @throw <code>domain_error</code> if y is negative or zero or
      *   if any element of y is NaN.
      */
     template <typename T_y>
-    inline bool check_positive(const char* function,
+    inline void check_positive(const char* function,
                                const char* name,
                                const T_y& y) {
-      return positive<T_y, is_vector_like<T_y>::value>
-        ::check(function, name, y);
+      positive<T_y, is_vector_like<T_y>::value>::check(function, name, y);
     }
 
   }
