@@ -8,7 +8,7 @@ namespace stan {
   namespace math {
 
     /**
-     * Return <code>true</code> if <code>y</code> is positive and finite.
+     * Check if <code>y</code> is positive and finite.
      *
      * This function is vectorized and will check each element of
      * <code>y</code>.
@@ -19,19 +19,15 @@ namespace stan {
      * @param name Variable name (for error messages)
      * @param y Variable to check
      *
-     * @return <code>true</code> if every element of y is greater than 0
-     *   and y is not infinite.
      * @throw <code>domain_error</code> if any element of y is not positive or
      *   if any element of y is NaN.
      */
     template <typename T_y>
-    inline bool check_positive_finite(const char* function,
+    inline void check_positive_finite(const char* function,
                                       const char* name,
                                       const T_y& y) {
       check_positive(function, name, y);
       check_finite(function, name, y);
-
-      return true;
     }
 
   }
