@@ -7,11 +7,10 @@
 #include <boost/math/tools/promotion.hpp>
 #include <cmath>
 #include <limits>
-#include <stdexcept>
 
 namespace stan {
-
   namespace math {
+
     /**
      * Return the lower- and upper-bounded scalar derived by
      * transforming the specified free scalar given the specified
@@ -44,7 +43,7 @@ namespace stan {
     typename boost::math::tools::promote_args<T, TL, TU>::type
     lub_constrain(const T x, TL lb, TU ub) {
       using std::exp;
-      stan::math::check_less("lub_constrain", "lb", lb, ub);
+      check_less("lub_constrain", "lb", lb, ub);
       if (lb == -std::numeric_limits<double>::infinity())
         return ub_constrain(x, ub);
       if (ub == std::numeric_limits<double>::infinity())
@@ -57,14 +56,14 @@ namespace stan {
         // Prevent x from reaching one unless it really really should.
         if ((x < std::numeric_limits<double>::infinity())
             && (inv_logit_x == 1))
-            inv_logit_x = 1 - 1e-15;
+          inv_logit_x = 1 - 1e-15;
       } else {
         T exp_x = exp(x);
         inv_logit_x = 1.0 - 1.0 / (1.0 + exp_x);
         // Prevent x from reaching zero unless it really really should.
         if ((x > -std::numeric_limits<double>::infinity())
             && (inv_logit_x== 0))
-            inv_logit_x = 1e-15;
+          inv_logit_x = 1e-15;
       }
       return lb + (ub - lb) * inv_logit_x;
     }
@@ -115,12 +114,7 @@ namespace stan {
     lub_constrain(const T x, const TL lb, const TU ub, T& lp) {
       using std::log;
       using std::exp;
-      if (!(lb < ub)) {
-        std::stringstream s;
-        s << "domain error in lub_constrain;  lower bound = " << lb
-          << " must be strictly less than upper bound = " << ub;
-        throw std::domain_error(s.str());
-      }
+      check_less("lub_constrain", "lb", lb, ub);
       if (lb == -std::numeric_limits<double>::infinity())
         return ub_constrain(x, ub, lp);
       if (ub == std::numeric_limits<double>::infinity())
@@ -133,7 +127,7 @@ namespace stan {
         // Prevent x from reaching one unless it really really should.
         if ((x < std::numeric_limits<double>::infinity())
             && (inv_logit_x == 1))
-            inv_logit_x = 1 - 1e-15;
+          inv_logit_x = 1 - 1e-15;
       } else {
         T exp_x = exp(x);
         inv_logit_x = 1.0 - 1.0 / (1.0 + exp_x);
@@ -141,13 +135,11 @@ namespace stan {
         // Prevent x from reaching zero unless it really really should.
         if ((x > -std::numeric_limits<double>::infinity())
             && (inv_logit_x== 0))
-            inv_logit_x = 1e-15;
+          inv_logit_x = 1e-15;
       }
       return lb + (ub - lb) * inv_logit_x;
     }
 
   }
-
 }
-
 #endif
