@@ -25,30 +25,20 @@
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     template <typename T_n, typename T_N, typename T_prob>
     typename return_type<T_prob>::type
     binomial_cdf_log(const T_n& n, const T_N& N, const T_prob& theta) {
-      static const char* function("stan::math::binomial_cdf_log");
+      static const char* function("binomial_cdf_log");
       typedef typename stan::partials_return_type<T_n, T_N, T_prob>::type
         T_partials_return;
 
-      using stan::math::check_finite;
-      using stan::math::check_bounded;
-      using stan::math::check_nonnegative;
-      using stan::math::value_of;
-      using stan::math::check_consistent_sizes;
-      using stan::math::include_summand;
-
-      // Ensure non-zero arguments lenghts
       if (!(stan::length(n) && stan::length(N) && stan::length(theta)))
         return 0.0;
 
       T_partials_return P(0.0);
 
-      // Validate arguments
       check_nonnegative(function, "Population size parameter", N);
       check_finite(function, "Probability parameter", theta);
       check_bounded(function, "Probability parameter", theta, 0.0, 1.0);
@@ -57,16 +47,11 @@ namespace stan {
                              "Population size parameter", N,
                              "Probability parameter", theta);
 
-      // Wrap arguments in vector views
       VectorView<const T_n> n_vec(n);
       VectorView<const T_N> N_vec(N);
       VectorView<const T_prob> theta_vec(theta);
       size_t size = max_size(n, N, theta);
 
-      // Compute vectorized cdf_log and gradient
-      using stan::math::value_of;
-      using stan::math::inc_beta;
-      using stan::math::lbeta;
       using std::exp;
       using std::pow;
       using std::log;
@@ -79,7 +64,7 @@ namespace stan {
       // but treated as negative infinity
       for (size_t i = 0; i < stan::length(n); i++) {
         if (value_of(n_vec[i]) < 0)
-          return operands_and_partials.value(stan::math::negative_infinity());
+          return operands_and_partials.value(negative_infinity());
       }
 
       for (size_t i = 0; i < size; i++) {
@@ -101,7 +86,6 @@ namespace stan {
           operands_and_partials.d_x1[i] -= pow(theta_dbl, n_dbl)
             * pow(1-theta_dbl, N_dbl-n_dbl-1) / betafunc / Pi;
       }
-
       return operands_and_partials.value(P);
     }
 
