@@ -19,7 +19,6 @@
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     /**
@@ -43,27 +42,19 @@ namespace stan {
               typename T_y, typename T_loc, typename T_scale>
     typename return_type<T_y, T_loc, T_scale>::type
     cauchy_log(const T_y& y, const T_loc& mu, const T_scale& sigma) {
-      static const char* function("stan::math::cauchy_log");
+      static const char* function("cauchy_log");
       typedef typename stan::partials_return_type<T_y, T_loc, T_scale>::type
         T_partials_return;
 
       using stan::is_constant_struct;
-      using stan::math::check_positive_finite;
-      using stan::math::check_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
-      using stan::math::value_of;
 
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(mu)
             && stan::length(sigma)))
         return 0.0;
 
-      // set up return value accumulator
       T_partials_return logp(0.0);
 
-      // validate args (here done over var, which should be OK)
       check_not_nan(function, "Random variable", y);
       check_finite(function, "Location parameter", mu);
       check_positive_finite(function, "Scale parameter", sigma);
@@ -72,15 +63,11 @@ namespace stan {
                              "Location parameter", mu,
                              "Scale parameter", sigma);
 
-      // check if no variables are involved and prop-to
       if (!include_summand<propto, T_y, T_loc, T_scale>::value)
         return 0.0;
 
-      using stan::math::log1p;
-      using stan::math::square;
       using std::log;
 
-      // set up template expressions wrapping scalars into vector views
       VectorView<const T_y> y_vec(y);
       VectorView<const T_loc> mu_vec(mu);
       VectorView<const T_scale> sigma_vec(sigma);
@@ -104,11 +91,9 @@ namespace stan {
         operands_and_partials(y, mu, sigma);
 
       for (size_t n = 0; n < N; n++) {
-        // pull out values of arguments
         const T_partials_return y_dbl = value_of(y_vec[n]);
         const T_partials_return mu_dbl = value_of(mu_vec[n]);
 
-        // reusable subexpression values
         const T_partials_return y_minus_mu
           = y_dbl - mu_dbl;
         const T_partials_return y_minus_mu_squared
@@ -118,7 +103,6 @@ namespace stan {
         const T_partials_return y_minus_mu_over_sigma_squared
           = y_minus_mu_over_sigma * y_minus_mu_over_sigma;
 
-        // log probability
         if (include_summand<propto>::value)
           logp += NEG_LOG_PI;
         if (include_summand<propto, T_scale>::value)
@@ -126,7 +110,6 @@ namespace stan {
         if (include_summand<propto, T_y, T_loc, T_scale>::value)
           logp -= log1p(y_minus_mu_over_sigma_squared);
 
-        // gradients
         if (!is_constant_struct<T_y>::value)
           operands_and_partials.d_x1[n] -= 2 * y_minus_mu
             / (sigma_squared[n] + y_minus_mu_squared);
@@ -148,7 +131,6 @@ namespace stan {
       return cauchy_log<false>(y, mu, sigma);
     }
 
-
   }
 }
 #endif
