@@ -20,7 +20,6 @@
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     // DoubleExponential(y|mu, sigma)  [sigma > 0]
@@ -30,28 +29,20 @@ namespace stan {
     typename return_type<T_y, T_loc, T_scale>::type
     double_exponential_log(const T_y& y,
                            const T_loc& mu, const T_scale& sigma) {
-      static const char* function("stan::math::double_exponential_log");
+      static const char* function("double_exponential_log");
       typedef typename stan::partials_return_type<T_y, T_loc, T_scale>::type
         T_partials_return;
 
       using stan::is_constant_struct;
-      using stan::math::check_finite;
-      using stan::math::check_positive_finite;
-      using stan::math::check_consistent_sizes;
-      using stan::math::value_of;
-      using stan::math::include_summand;
       using std::log;
       using std::fabs;
-      using stan::math::sign;
       using std::log;
 
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(mu)
             && stan::length(sigma)))
         return 0.0;
 
-      // set up return value accumulator
       T_partials_return logp(0.0);
       check_finite(function, "Random variable", y);
       check_finite(function, "Location parameter", mu);
@@ -61,11 +52,9 @@ namespace stan {
                              "Location parameter", mu,
                              "Shape parameter", sigma);
 
-      // check if no variables are involved and prop-to
       if (!include_summand<propto, T_y, T_loc, T_scale>::value)
         return 0.0;
 
-      // set up template expressions wrapping scalars into vector views
       VectorView<const T_y> y_vec(y);
       VectorView<const T_loc> mu_vec(mu);
       VectorView<const T_scale> sigma_vec(sigma);
@@ -90,16 +79,13 @@ namespace stan {
           inv_sigma_squared[i] = inv_sigma[i] * inv_sigma[i];
       }
 
-
       for (size_t n = 0; n < N; n++) {
         const T_partials_return y_dbl = value_of(y_vec[n]);
         const T_partials_return mu_dbl = value_of(mu_vec[n]);
 
-        // reusable subexpressions values
         const T_partials_return y_m_mu = y_dbl - mu_dbl;
         const T_partials_return fabs_y_m_mu = fabs(y_m_mu);
 
-        // log probability
         if (include_summand<propto>::value)
           logp += NEG_LOG_TWO;
         if (include_summand<propto, T_scale>::value)
@@ -107,7 +93,6 @@ namespace stan {
         if (include_summand<propto, T_y, T_loc, T_scale>::value)
           logp -= fabs_y_m_mu * inv_sigma[n];
 
-        // gradients
         T_partials_return sign_y_m_mu_times_inv_sigma(0);
         if (contains_nonconstant_struct<T_y, T_loc>::value)
           sign_y_m_mu_times_inv_sigma = sign(y_m_mu) * inv_sigma[n];
@@ -124,13 +109,13 @@ namespace stan {
       return operands_and_partials.value(logp);
     }
 
-
     template <typename T_y, typename T_loc, typename T_scale>
     typename return_type<T_y, T_loc, T_scale>::type
     double_exponential_log(const T_y& y, const T_loc& mu,
                            const T_scale& sigma) {
       return double_exponential_log<false>(y, mu, sigma);
     }
+
   }
 }
 #endif
