@@ -23,7 +23,6 @@
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     template <typename T_y, typename T_shape, typename T_scale>
@@ -32,16 +31,11 @@ namespace stan {
       typedef typename stan::partials_return_type<T_y, T_shape, T_scale>::type
         T_partials_return;
 
-      static const char* function("stan::math::frechet_cdf_log");
+      static const char* function("frechet_cdf_log");
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_positive;
-      using stan::math::check_nonnegative;
       using boost::math::tools::promote_args;
-      using stan::math::value_of;
       using std::log;
 
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(alpha)
             && stan::length(sigma)))
@@ -65,10 +59,8 @@ namespace stan {
         const T_partials_return alpha_dbl = value_of(alpha_vec[n]);
         const T_partials_return pow_ = pow(sigma_dbl / y_dbl, alpha_dbl);
 
-        // cdf_log
         cdf_log -= pow_;
 
-        // gradients
         if (!is_constant_struct<T_y>::value)
           operands_and_partials.d_x1[n] += pow_ * alpha_dbl / y_dbl;
         if (!is_constant_struct<T_shape>::value)
@@ -76,9 +68,9 @@ namespace stan {
         if (!is_constant_struct<T_scale>::value)
           operands_and_partials.d_x3[n] -= pow_ * alpha_dbl / sigma_dbl;
       }
-
       return operands_and_partials.value(cdf_log);
     }
+
   }
 }
 #endif
