@@ -23,8 +23,8 @@ namespace stan {
 
     template <class RNG>
     inline double
-    frechet_rng(const double alpha,
-                const double sigma,
+    frechet_rng(double alpha,
+                double sigma,
                 RNG& rng) {
       using boost::variate_generator;
       using boost::random::weibull_distribution;
