@@ -23,22 +23,16 @@ namespace stan {
     template <typename T_y, typename T_loc, typename T_scale>
     typename return_type<T_y, T_loc, T_scale>::type
     lognormal_ccdf_log(const T_y& y, const T_loc& mu, const T_scale& sigma) {
-      static const char* function("stan::math::lognormal_ccdf_log");
+      static const char* function("lognormal_ccdf_log");
       typedef typename stan::partials_return_type<T_y, T_loc, T_scale>::type
         T_partials_return;
 
       T_partials_return ccdf_log = 0.0;
 
-      using stan::math::check_not_nan;
-      using stan::math::check_finite;
-      using stan::math::check_nonnegative;
-      using stan::math::check_positive_finite;
       using boost::math::tools::promote_args;
-      using stan::math::value_of;
       using std::log;
       using std::exp;
 
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(mu)
             && stan::length(sigma)))
@@ -57,7 +51,7 @@ namespace stan {
       VectorView<const T_scale> sigma_vec(sigma);
       size_t N = max_size(y, mu, sigma);
 
-      const double sqrt_pi = std::sqrt(stan::math::pi());
+      const double sqrt_pi = std::sqrt(pi());
 
       for (size_t i = 0; i < stan::length(y); i++) {
         if (value_of(y_vec[i]) == 0.0)
@@ -75,11 +69,9 @@ namespace stan {
         const T_partials_return rep_deriv = SQRT_2 / sqrt_pi
           * exp(-scaled_diff * scaled_diff) / sigma_dbl;
 
-        // ccdf_log
         const T_partials_return erfc_calc = erfc(scaled_diff);
         ccdf_log += log_half + log(erfc_calc);
 
-        // gradients
         if (!is_constant_struct<T_y>::value)
           operands_and_partials.d_x1[n] -= rep_deriv / erfc_calc / y_dbl;
         if (!is_constant_struct<T_loc>::value)
@@ -88,9 +80,9 @@ namespace stan {
           operands_and_partials.d_x3[n] += rep_deriv * scaled_diff * SQRT_2
             / erfc_calc;
       }
-
       return operands_and_partials.value(ccdf_log);
     }
+
   }
 }
 #endif
