@@ -16,29 +16,20 @@
 #include <boost/random/variate_generator.hpp>
 
 namespace stan {
-
   namespace math {
 
     template <typename T_y, typename T_low, typename T_high>
     typename return_type<T_y, T_low, T_high>::type
     uniform_cdf(const T_y& y, const T_low& alpha, const T_high& beta) {
-      static const char* function("stan::math::uniform_cdf");
+      static const char* function("uniform_cdf");
       typedef typename stan::partials_return_type<T_y, T_low, T_high>::type
         T_partials_return;
 
-      using stan::math::check_not_nan;
-      using stan::math::check_finite;
-      using stan::math::check_greater;
-      using stan::math::value_of;
-      using stan::math::check_consistent_sizes;
-
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(alpha)
             && stan::length(beta)))
         return 1.0;
 
-      // set up return value accumulator
       T_partials_return cdf(1.0);
       check_not_nan(function, "Random variable", y);
       check_finite(function, "Lower bound parameter", alpha);
@@ -70,10 +61,8 @@ namespace stan {
         const T_partials_return b_min_a = beta_dbl - alpha_dbl;
         const T_partials_return cdf_ = (y_dbl - alpha_dbl) / b_min_a;
 
-        // cdf
         cdf *= cdf_;
 
-        // gradients
         if (!is_constant_struct<T_y>::value)
           operands_and_partials.d_x1[n] += 1.0 / b_min_a / cdf_;
         if (!is_constant_struct<T_low>::value)
@@ -98,6 +87,7 @@ namespace stan {
 
       return operands_and_partials.value(cdf);
     }
+
   }
 }
 #endif
