@@ -1,8 +1,6 @@
 #ifndef STAN_MATH_REV_CORE_NESTED_SIZE_HPP
 #define STAN_MATH_REV_CORE_NESTED_SIZE_HPP
 
-#include <stan/math/rev/core/chainable.hpp>
-#include <stan/math/rev/core/chainable_alloc.hpp>
 #include <stan/math/rev/core/chainablestack.hpp>
 #include <cstdlib>
 
