@@ -12,7 +12,7 @@ namespace stan {
       class inv_vari : public op_v_vari {
       public:
         explicit inv_vari(vari* avi) :
-          op_v_vari(stan::math::inv(avi->val_), avi) {
+          op_v_vari(inv(avi->val_), avi) {
         }
         void chain() {
           avi_->adj_ -= adj_ / (avi_->val_ * avi_->val_);
